==> haskell-crypto-random-0.0.9-297-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-7gQFhjJtH6ZCfBMBOrJKfm
key:                  crypto-random-0.0.9-7gQFhjJtH6ZCfBMBOrJKfm
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  e11168891aff396de0d0dad40e4679dc
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-random
hs-libraries:         HScrypto-random-0.0.9-7gQFhjJtH6ZCfBMBOrJKfm
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    securemem-0.1.10-IeO5K0X0mzS7xQCiSaDnT0 unix-2.7.2.2
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-GvetF5f2h7rHNGt5A4YC42
key:                  crypto-random-0.0.9-GvetF5f2h7rHNGt5A4YC42
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  6acf466caf5a7f60eae520e289087be7
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-random
hs-libraries:         HScrypto-random-0.0.9-GvetF5f2h7rHNGt5A4YC42
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    securemem-0.1.10-4t0HOlz4MW924hJuNe1SSf unix-2.7.2.2
    vector-0.13.0.0-9fyHsAonVFcGYv9jtLmfSh

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
